@@ -13,8 +13,8 @@ Usage::
 """
 from typing import Any, Dict, Type
 
+from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
 
 from mypy_boto3_forecastquery.type_defs import QueryForecastResponseTypeDef
 
@@ -22,17 +22,17 @@ __all__ = ("ForecastQueryServiceClient",)
 
 
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    InvalidInputException: Type[Boto3ClientError]
-    InvalidNextTokenException: Type[Boto3ClientError]
-    LimitExceededException: Type[Boto3ClientError]
-    ResourceInUseException: Type[Boto3ClientError]
-    ResourceNotFoundException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    InvalidInputException: Type[BotocoreClientError]
+    InvalidNextTokenException: Type[BotocoreClientError]
+    LimitExceededException: Type[BotocoreClientError]
+    ResourceInUseException: Type[BotocoreClientError]
+    ResourceNotFoundException: Type[BotocoreClientError]
 
 
 class ForecastQueryServiceClient:
     """
-    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/forecastquery.html#ForecastQueryService.Client)
+    [ForecastQueryService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/forecastquery.html#ForecastQueryService.Client)
     """
 
     meta: ClientMeta
@@ -40,7 +40,7 @@ class ForecastQueryServiceClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/forecastquery.html#ForecastQueryService.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -51,7 +51,7 @@ class ForecastQueryServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/forecastquery.html#ForecastQueryService.Client.generate_presigned_url)
         """
 
     def query_forecast(
@@ -63,5 +63,5 @@ class ForecastQueryServiceClient:
         NextToken: str = None,
     ) -> QueryForecastResponseTypeDef:
         """
-        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.53/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
+        [Client.query_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
         """
